# sequencelib: python library for reading, writing, and analyzing biological sequences

Using classes and methods in sequencelib.py it is possible to read and write textfiles containing DNA or protein-sequences (possibly aligned) and to analyze and manipulate the sequence in various ways.

## Availability

The sequencelib.py module is available on GitHub: https://github.com/agormp/sequencelib and on PyPI: https://pypi.org/project/sequencelib/

## Installation

```
python3 -m pip install sequencelib
```

## Highlights

To be written